;;; @(#) Kinem
;;; stream kinematic wave model
;;; $Lastupdate: Fri Jan  5 09:54:30 2001 $

------------------------------------------------------------------------
* summary

This directory contains kinem.h,cc and the sample files of the simulations.
These files are available on ohymos-2.0 or later.

 o kinem.h : definition of the class Kinem
 o kinem.cc : implimentation of the class Kinem

The class Kinem is a stream kinematic wave model derived from the class 
Element, which is contained in the ohymos directory. This class uses 
Manning formula as flow resistance law.

The momentum equation is as follows:

  Q = alpha * pow(A, m)

  Q     : discharge (m3/s)
  A     : flow cross-sectional area (m2)
  R     : hydraulic radius (m2)
  K, Z  : constants in R = K * pow(A, Z)
  n     : Manning coefficient (m-s)
  i     : bed slope gradient (-)
  m     : exponent of A in momentum equation; if using Manning formula, 
          m = 2/3*Z + 1.
  alpha : constant (= pow(K, 2/3)*\sqrt(i)/n) (m-s)

This equation and the continuity equation are solved by using FDM 
scheme developed by Beven(1979).

------------------------------------------------------------------------
* class name

  Kinem

------------------------------------------------------------------------
* receive ports

Kinem has two types of receive ports. One is for receiving upstream inflow
discharge from upper end of the stream, and the other is for receiving 
lateral inflow discharge from slope area. The numbers of the receive ports 
are variable, which are given in the constructor of Kinem. The type of 
both ports is Receive<double>. 

The object_name of the ports for upstream inflow discharge is "rpu" and 
the object_name of the ports for lateral inflow discharge is "rpl".
The object_numbers are [0,1,...,n-1] (n is the number of the each port).
The unit of the discharges is m3/s.

------------------------------------------------------------------------
* send ports

Kinem has a send port for sending outflow discharge from lower end of the 
stream. The port type is Send<double>. 

The object_name is "sp" and the object_number is 0. The unit of the discharge
is m3/s.

------------------------------------------------------------------------
* parameter file and initial state file

------------------------------------------------------------------------
** parameter file

Function Kinem::Set_parameter(FILE* fp) reads a parameter file.
This function reads parameter values as follows:

	fscanf(fp, "%lf %lf %lf %lf %d %ld %lf", 
			   &mL, &mB, &mG, &mMan, &mDiv, &mDt, &mTheta)

	for (int i = 0; i <= mDiv; i++)	fscanf(fp, "%lf", &mK[i]);
	for (int i = 0; i <= mDiv; i++)	fscanf(fp, "%lf", &mZ[i]);

mL : stream length (m)
mB : stream width (m)
mG : bed slope gradient (-)
mMan : Manning coefficient (m-s)
mDiv : number of spatial division in FDM (-)
mDt : time step (s)
mTheta : weighting factor used in FDM (0.5 $B!A(B 1.0, standard value is 0.65)
mK[i] : K at each computation section
mZ[i] : Z at each computation section

The values of mK and mZ must be given at each computation section.
"tkinem.pmt" and "tkinemscf.pmt" are the example.

------------------------------------------------------------------------
** initial state file

Function Kinem::Set_initial_state(FILE* fp) reads an initial state file.
This function reads initial state value as follows:

	fscanf(fp, "%ld", &current_time)

current_time : simulation starting time (s)

"tkinem.ist" and "tkinemscf.ist" are the example.

------------------------------------------------------------------------
* output

Outflow discharge hydrograph at the lower end of the stream

------------------------------------------------------------------------
* compile

To compile, type

% make

then the executable files "tkinem" and "ohymos" will be generated. "tkinem" 
is available on ohymos ver.2.0 or later and "ohymos" is available on 
ohymos ver. 3.0 or later. "ohymos" uses SCF-style model building which 
is supported in ohymos ver. 3.0.

"tkinem" uses the files "tkinem.*" and "ohymos" uses the files "tkinemscf.*".

------------------------------------------------------------------------
* bibliography

Beven, K (1979) :
On the Generalized Kinematic Routing Method, 
Water Resources Research, VOL. 15, NO. 5, pp. 1238--1242.

;;; Local Variables: ***
;;; mode: Outline ***
;;; indent-tabs-mode: nil ***
;;; tab-width: 8 ***
;;; End: ***
